@@ -1,4 +1,8 @@
-from worker import constants
+import importlib
+import worker
+importlib.reload(worker)
+from worker import constants  # noqa: #402
+
 
 constants.update({
     "global": {
@@ -9,6 +13,7 @@ constants.update({
     },
     "drilling-efficiency": {
         "mse": {
+            "lookback-duration": 30,
             "export-duration": 30,  # update and export results every 30 seconds
             "drilling-activity": ["Rotary Drilling", "Slide Drilling"],
             "required-channels": ['weight_on_bit', 'rotary_rpm', 'rotary_torque', 'rop'],
