@@ -1,8 +1,6 @@
 from testcase.state_testing_app.state_testing_app import TestingApp
-from worker.framework.timeout_handler import timeout_track
 
 
-@timeout_track(default_timeout=30)
 def lambda_handler(event, context):
     """
     This function is the main entry point of the AWS Lambda function
