@@ -1,3 +1,4 @@
+import json
 import os
 import unittest
 
@@ -11,7 +12,11 @@ class TestRollbarPayloadHandler(unittest.TestCase):
             os.path.join(os.path.dirname(__file__), '..', 'resources', 'test', 'original_rollbar_payload.json')
         )
         original_payload = file_to_json(original_payload)
-        self.assertEqual(len(original_payload["data"]["body"]["trace"]["frames"][1]["locals"]["dataset"]), 23)
+        self.assertEqual(
+            len(json.dumps(original_payload["data"]["body"]["trace"]["frames"][1]["locals"]["dataset"])), 12903
+        )
 
         trimmed_payload = payload_handler(original_payload)
-        self.assertEqual(len(trimmed_payload["data"]["body"]["trace"]["frames"][1]["locals"]["dataset"]), 3)
+
+        # After trimming, the local becomes a string with reduced number of characters
+        self.assertEqual(len(trimmed_payload["data"]["body"]["trace"]["frames"][1]["locals"]["dataset"]), 1127)
