@@ -1,4 +1,3 @@
-import time
 from typing import List, Union
 
 from worker.app.modules import Module
@@ -69,13 +68,10 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         batch_size = len(event)
         start_time = event[0].get("timestamp")
         end_time = event[-1].get("timestamp")
-        system_time = time.time()
 
-        self.debug(
+        self.log(
             self.asset_id,
-            "Received {} elements from {} to {} at {}. {} seconds of initial data are lookback.".format(
-                batch_size, start_time, end_time, system_time, max_lookback_seconds
-            )
+            text=f"Received {batch_size} elements from {start_time} to {end_time}. {max_lookback_seconds} seconds of initial data are lookback."
         )
 
     @staticmethod
