@@ -137,7 +137,12 @@ class AppTestRun:
                 )
                 if not wits:
                     continue
-                event = [wits]
+
+                event = [{
+                    'metadata': {},
+                    'records': wits
+                }]
+
             self.lambda_handler(event, None)
             self.progress.set_description(schedule_time)
 
